<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.2/1886137
 */
namespace Application\Helper;

/**
 * Helper functions for dealing with strings
 * @package Application\Helper
 */
class StringHelper
{
    /**
     * Make sure that a string is bookended with double quotes
     * @param  string      $str         The string to quote
     * @return string the quoted string or the original string if already quoted
     */
    public static function quoteString(string $str) : string
    {
        return ($str[0] != '"' || substr($str, -1) != '"') ? $str = '"' . $str . '"' : $str;
    }

    /**
     * Quote all the strings in the array and return the strings
     * @param array         $array  array of strings
     * @param string|null   $key    optional key to use within the array
     * @return array
     */
    public static function quoteStrings(array $array, string $key = null) : array
    {
        return array_map(
            function ($string) {
                return StringHelper::quoteString($string);
            },
            $key ? $array[$key] : $array
        );
    }
}
